@@ -1,8 +1,8 @@
 """Main configuration manager with simplified workspace rules."""
 
+import asyncio
 import json
 import os
-import sys
 
 from pathlib import Path
 from typing import Any
@@ -14,6 +14,7 @@ import inquirer
 
 from workato_platform_cli import Workato
 from workato_platform_cli.cli.commands.projects.project_manager import ProjectManager
+from workato_platform_cli.cli.utils.token_input import get_token_with_smart_paste
 from workato_platform_cli.client.workato_api.configuration import Configuration
 from workato_platform_cli.client.workato_api.models.project import Project
 
@@ -143,6 +144,14 @@ class ConfigManager:
             region_info = self._match_host_to_region(api_url)
             region = region_info.region
 
+        # Validate credentials are available before attempting authentication
+        if not api_token:
+            raise click.ClickException(
+                f"Profile '{current_profile_name}' exists but credentials not found "
+                "in keychain. Please run 'workato init' interactively or set "
+                "WORKATO_API_TOKEN environment variable."
+            )
+
         # Map region to URL
         if region == "custom":
             if not api_url:
@@ -328,26 +337,51 @@ class ConfigManager:
 
             answers: dict[str, str] = inquirer.prompt(questions)
             if not answers:
-                click.echo("❌ No profile selected")
-                sys.exit(1)
+                raise click.ClickException("No profile selected")
 
             if answers["profile_choice"] == "Create new profile":
                 profile_name = (
                     await click.prompt("Enter new profile name", type=str)
                 ).strip()
                 if not profile_name:
-                    click.echo("❌ Profile name cannot be empty")
-                    sys.exit(1)
+                    raise click.ClickException("Profile name cannot be empty")
                 await self._create_new_profile(profile_name)
             else:
                 profile_name = answers["profile_choice"]
+
+                # Check if credentials exist in keychain for existing profile
+                existing_profile = self.profile_manager.get_profile(profile_name)
+                token = self.profile_manager._get_token_from_keyring(profile_name)
+
+                if existing_profile and not token:
+                    # Credentials missing from keychain - prompt for re-entry
+                    click.echo("⚠️  Credentials not found for this profile")
+
+                    # Get region info from existing profile
+                    region_info = RegionInfo(
+                        region=existing_profile.region,
+                        url=existing_profile.region_url,
+                        name=existing_profile.region,
+                    )
+
+                    # Prompt and validate credentials
+                    (
+                        profile_data,
+                        validated_token,
+                    ) = await self._prompt_and_validate_credentials(
+                        profile_name, region_info
+                    )
+
+                    # Update profile with validated credentials
+                    self.profile_manager.set_profile(
+                        profile_name, profile_data, validated_token
+                    )
         else:
             profile_name = (
                 await click.prompt("Enter profile name", default="default", type=str)
             ).strip()
             if not profile_name:
-                click.echo("❌ Profile name cannot be empty")
-                sys.exit(1)
+                raise click.ClickException("Profile name cannot be empty")
             await self._create_new_profile(profile_name)
 
         # Set as current profile
@@ -380,8 +414,7 @@ class ConfigManager:
 
             answers: dict[str, str] = inquirer.prompt(questions)
             if not answers:
-                click.echo("❌ No profile selected")
-                sys.exit(1)
+                raise click.ClickException("No profile selected")
 
             selected_choice: str = answers["profile_choice"]
             if selected_choice == "Create new profile":
@@ -390,8 +423,7 @@ class ConfigManager:
                 )
                 profile_name = new_profile_input.strip()
                 if not profile_name:
-                    click.echo("❌ Profile name cannot be empty")
-                    sys.exit(1)
+                    raise click.ClickException("Profile name cannot be empty")
                 return profile_name
             else:
                 # Warn user about overwriting existing profile
@@ -400,8 +432,7 @@ class ConfigManager:
                     f"'{selected_choice}' with the environment variables."
                 )
                 if not click.confirm("Continue?", default=True):
-                    click.echo("❌ Cancelled")
-                    sys.exit(1)
+                    raise click.ClickException("Operation cancelled")
                 return selected_choice
         else:
             default_profile_input: str = await click.prompt(
@@ -409,8 +440,7 @@ class ConfigManager:
             )
             profile_name = default_profile_input.strip()
             if not profile_name:
-                click.echo("❌ Profile name cannot be empty")
-                sys.exit(1)
+                raise click.ClickException("Profile name cannot be empty")
             return profile_name
 
     async def _create_profile_with_env_vars(
@@ -431,8 +461,7 @@ class ConfigManager:
             region_result = await self.profile_manager.select_region_interactive()
 
             if not region_result:
-                click.echo("❌ Setup cancelled")
-                sys.exit(1)
+                raise click.ClickException("Setup cancelled")
 
             selected_region = region_result
 
@@ -441,10 +470,12 @@ class ConfigManager:
             token = env_token
         else:
             click.echo()
-            token = await click.prompt("Enter your Workato API token", hide_input=True)
+            token = await asyncio.to_thread(
+                get_token_with_smart_paste,
+                prompt_text="API token",
+            )
             if not token.strip():
-                click.echo("❌ No token provided")
-                sys.exit(1)
+                raise click.ClickException("API token cannot be empty")
 
         # Test authentication and get workspace info
         click.echo("🔄 Testing authentication with environment variables...")
@@ -468,6 +499,49 @@ class ConfigManager:
         click.echo(f"✅ Authenticated as: {user_info.name}")
         click.echo("✓ Using environment variables for authentication")
 
+    async def _prompt_and_validate_credentials(
+        self, profile_name: str, region_info: RegionInfo
+    ) -> tuple[ProfileData, str]:
+        """Prompt for API credentials and validate them with an API call.
+        Args:
+            profile_name: Name of the profile being configured
+            region_info: Region information containing the API URL
+        Returns:
+            tuple[ProfileData, str]: Validated profile data and API token
+        Raises:
+            click.ClickException: If token is empty or validation fails
+        """
+        # Prompt for API token
+        click.echo("🔐 Enter your API token")
+        token = await click.prompt("Enter your Workato API token", hide_input=True)
+
+        # Validate token is not empty
+        if not token.strip():
+            raise click.ClickException("API token cannot be empty")
+
+        # Create API configuration with the token and region URL
+        api_config = Configuration(
+            access_token=token, host=region_info.url, ssl_ca_cert=certifi.where()
+        )
+
+        # Make API call to test authentication and get workspace info
+        async with Workato(configuration=api_config) as workato_api_client:
+            user_info = await workato_api_client.users_api.get_workspace_details()
+
+        # Create and return ProfileData object with workspace info
+        if not region_info.url:
+            raise click.ClickException("Region URL is required")
+
+        profile_data = ProfileData(
+            region=region_info.region,
+            region_url=region_info.url,
+            workspace_id=user_info.id,
+        )
+
+        click.echo(f"✅ Authenticated as: {user_info.name}")
+
+        return profile_data, token
+
     async def _create_new_profile(self, profile_name: str) -> None:
         """Create a new profile interactively"""
         # Select region
@@ -475,17 +549,17 @@ class ConfigManager:
         region_result = await self.profile_manager.select_region_interactive()
 
         if not region_result:
-            click.echo("❌ Setup cancelled")
-            sys.exit(1)
+            raise click.ClickException("Setup cancelled")
 
         selected_region = region_result
 
         # Get API token
-        click.echo("🔐 Enter your API token")
-        token = await click.prompt("Enter your Workato API token", hide_input=True)
+        token = await asyncio.to_thread(
+            get_token_with_smart_paste,
+            prompt_text="API token",
+        )
         if not token.strip():
-            click.echo("❌ No token provided")
-            sys.exit(1)
+            raise click.ClickException("API token cannot be empty")
 
         # Test authentication and get workspace info
         api_config = Configuration(
@@ -504,8 +578,8 @@ class ConfigManager:
             workspace_id=user_info.id,
         )
 
+        # Save profile and token
         self.profile_manager.set_profile(profile_name, profile_data, token)
-        click.echo(f"✅ Authenticated as: {user_info.name}")
 
     async def _setup_project(self, profile_name: str, workspace_root: Path) -> None:
         """Setup project interactively"""
@@ -540,16 +614,14 @@ class ConfigManager:
 
             answers = inquirer.prompt(questions)
             if not answers:
-                click.echo("❌ No project selected")
-                sys.exit(1)
+                raise click.ClickException("No project selected")
 
             selected_project = None
 
             if answers["project"] == "Create new project":
                 project_name = await click.prompt("Enter project name", type=str)
                 if not project_name or not project_name.strip():
-                    click.echo("❌ Project name cannot be empty")
-                    sys.exit(1)
+                    raise click.ClickException("Project name cannot be empty")
 
                 click.echo(f"🔨 Creating project: {project_name}")
                 selected_project = await project_manager.create_project(project_name)
@@ -562,8 +634,7 @@ class ConfigManager:
                         break
 
             if not selected_project:
-                click.echo("❌ No project selected")
-                sys.exit(1)
+                raise click.ClickException("No project selected")
 
             # Check if this specific project already exists locally in the workspace
             local_projects = self._find_all_projects(workspace_root)
@@ -593,8 +664,7 @@ class ConfigManager:
                     "This may overwrite or delete local files.",
                     default=False,
                 ):
-                    click.echo("❌ Initialization cancelled")
-                    sys.exit(1)
+                    raise click.ClickException("Initialization cancelled")
                 # Use existing path instead of creating new one
                 project_path = existing_local_path
             else:
@@ -608,8 +678,7 @@ class ConfigManager:
                     project_path, workspace_root
                 )
             except ValueError as e:
-                click.echo(f"❌ {e}")
-                sys.exit(1)
+                raise click.ClickException(str(e)) from e
 
             # Check if project directory already exists and is non-empty
             if not project_path.exists():
@@ -993,28 +1062,24 @@ Thumbs.db
         except (json.JSONDecodeError, OSError):
             existing_name = "Unknown"
 
-        click.echo(
-            f"❌ Directory contains different Workato project: "
-            f"{existing_name} (ID: {existing_project_id})"
-        )
-        click.echo(
+        raise click.ClickException(
+            f"Directory contains different Workato project: "
+            f"{existing_name} (ID: {existing_project_id})\n"
             f"   Cannot initialize {selected_project.name} "
-            f"(ID: {selected_project.id}) here"
+            f"(ID: {selected_project.id}) here\n"
+            f"💡 Choose a different directory or project name"
         )
-        click.echo("💡 Choose a different directory or project name")
-        sys.exit(1)
 
     def _handle_non_empty_directory_error(
         self, project_path: Path, workspace_root: Path, existing_files: list
     ) -> None:
         """Handle error when directory is non-empty but not a Workato project."""
-        click.echo(
-            f"❌ Project directory is not empty: "
-            f"{project_path.relative_to(workspace_root)}"
+        raise click.ClickException(
+            f"Project directory is not empty: "
+            f"{project_path.relative_to(workspace_root)}\n"
+            f"   Found {len(existing_files)} existing files\n"
+            f"💡 Choose a different project name or clean the directory first"
         )
-        click.echo(f"   Found {len(existing_files)} existing files")
-        click.echo("💡 Choose a different project name or clean the directory first")
-        sys.exit(1)
 
     # Credential management
 
@@ -1022,12 +1087,11 @@ Thumbs.db
         """Validate credentials and exit if missing"""
         is_valid, missing_items = self.validate_environment_config()
         if not is_valid:
-            click.echo("❌ Missing required credentials:")
-            for item in missing_items:
-                click.echo(f"   • {item}")
-            click.echo()
-            click.echo("💡 Run 'workato init' to set up authentication")
-            sys.exit(1)
+            error_msg = "Missing required credentials:\n" + "\n".join(
+                f"   • {item}" for item in missing_items
+            )
+            error_msg += "\n\n💡 Run 'workato init' to set up authentication"
+            raise click.ClickException(error_msg)
 
     def validate_environment_config(self) -> tuple[bool, list[str]]:
         """Validate environment configuration"""
